searchData={"items":[{"type":"module","title":"Cogito","doc":"A common module for the project.\n\nKnown parsers:\n* json\n* logic formulas\n\nBut you can easily build your own.","ref":"Cogito.html"},{"type":"function","title":"Cogito.parse/2","doc":"Parses a string, abstracting from the internal implementation of the parser.","ref":"Cogito.html#parse/2"},{"type":"module","title":"Cogito.Combinators","doc":"A list of basic combinators.\n\nBuilding example (collect primitive):\n\n```elixir\n[\n  parser,\n  [\n    ws(),\n    delimiter,\n    ws(),\n    parser\n  ]\n  |> nth(1)\n  |> many()\n]\n|> fseq(fn [h, t] -> [h | t] end)\n|> option([])\n```\n\nThe meaning of each of them is derived from the names.","ref":"Cogito.Combinators.html"},{"type":"function","title":"Cogito.Combinators.between/3","doc":"Don't use it with `Cogito.Primitives.ws()` because `nth(1)` will break everything.","ref":"Cogito.Combinators.html#between/3"},{"type":"function","title":"Cogito.Combinators.char/1","doc":"","ref":"Cogito.Combinators.html#char/1"},{"type":"function","title":"Cogito.Combinators.choice/1","doc":"","ref":"Cogito.Combinators.html#choice/1"},{"type":"function","title":"Cogito.Combinators.eos/1","doc":"","ref":"Cogito.Combinators.html#eos/1"},{"type":"function","title":"Cogito.Combinators.eos!/1","doc":"","ref":"Cogito.Combinators.html#eos!/1"},{"type":"function","title":"Cogito.Combinators.fseq/2","doc":"","ref":"Cogito.Combinators.html#fseq/2"},{"type":"function","title":"Cogito.Combinators.identity/1","doc":"","ref":"Cogito.Combinators.html#identity/1"},{"type":"function","title":"Cogito.Combinators.ignore/1","doc":"","ref":"Cogito.Combinators.html#ignore/1"},{"type":"function","title":"Cogito.Combinators.join/1","doc":"","ref":"Cogito.Combinators.html#join/1"},{"type":"macro","title":"Cogito.Combinators.lazy/1","doc":"","ref":"Cogito.Combinators.html#lazy/1"},{"type":"function","title":"Cogito.Combinators.many1/1","doc":"","ref":"Cogito.Combinators.html#many1/1"},{"type":"function","title":"Cogito.Combinators.many/1","doc":"","ref":"Cogito.Combinators.html#many/1"},{"type":"function","title":"Cogito.Combinators.map/2","doc":"","ref":"Cogito.Combinators.html#map/2"},{"type":"function","title":"Cogito.Combinators.nth/2","doc":"","ref":"Cogito.Combinators.html#nth/2"},{"type":"function","title":"Cogito.Combinators.option/2","doc":"","ref":"Cogito.Combinators.html#option/2"},{"type":"function","title":"Cogito.Combinators.repeat/2","doc":"","ref":"Cogito.Combinators.html#repeat/2"},{"type":"function","title":"Cogito.Combinators.seq/1","doc":"","ref":"Cogito.Combinators.html#seq/1"},{"type":"module","title":"Cogito.Json","doc":"A classic example of json parsing.\n\nPossible inputs:\n* `[[], [1], 2, [[3, []]]]`\n* `[1, {a: \\\"Daniil Serov\\\", b: [1, 2, 3]}, null]`\n* `{employees: [{John: {age: 20, car: null}}, {Anna: {age: 23, car: \\\"Lada\\\"}}]}`","ref":"Cogito.Json.html"},{"type":"function","title":"Cogito.Json.array/0","doc":"","ref":"Cogito.Json.html#array/0"},{"type":"function","title":"Cogito.Json.entry/0","doc":"","ref":"Cogito.Json.html#entry/0"},{"type":"function","title":"Cogito.Json.object/0","doc":"","ref":"Cogito.Json.html#object/0"},{"type":"function","title":"Cogito.Json.parser/0","doc":"","ref":"Cogito.Json.html#parser/0"},{"type":"function","title":"Cogito.Json.parser!/0","doc":"","ref":"Cogito.Json.html#parser!/0"},{"type":"function","title":"Cogito.Json.value/0","doc":"","ref":"Cogito.Json.html#value/0"},{"type":"module","title":"Cogito.Logic","doc":"Logic formulas parser.\n\nReturns the parsing tree from:\n* `{:impl, l, r}` – implication\n* `{:dsj, l, r}` – disjunction\n* `{:cnj, l, r}` – conjunction\n* `{:neg, e}` – negation\n* `{:var, n}` – variable\n* `:false` – false\n\nNote that `{:neg, e}` equivalent to `{:impl, e, :false}`.","ref":"Cogito.Logic.html"},{"type":"module","title":"Cogito.Primitives","doc":"A list of primitive parsers.\n\nThe best way to use it:\n\n```elixir\nimport Cogito.Combinators\nimport Cogito.Primitives\n\nrequire Cogito.Combinators\n```","ref":"Cogito.Primitives.html"},{"type":"function","title":"Cogito.Primitives.between_ws/1","doc":"","ref":"Cogito.Primitives.html#between_ws/1"},{"type":"function","title":"Cogito.Primitives.chars/1","doc":"","ref":"Cogito.Primitives.html#chars/1"},{"type":"function","title":"Cogito.Primitives.collect/2","doc":"","ref":"Cogito.Primitives.html#collect/2"},{"type":"function","title":"Cogito.Primitives.digit/0","doc":"","ref":"Cogito.Primitives.html#digit/0"},{"type":"function","title":"Cogito.Primitives.float/0","doc":"","ref":"Cogito.Primitives.html#float/0"},{"type":"function","title":"Cogito.Primitives.identifier/0","doc":"","ref":"Cogito.Primitives.html#identifier/0"},{"type":"function","title":"Cogito.Primitives.integer/0","doc":"","ref":"Cogito.Primitives.html#integer/0"},{"type":"function","title":"Cogito.Primitives.letter/0","doc":"","ref":"Cogito.Primitives.html#letter/0"},{"type":"function","title":"Cogito.Primitives.letter_or_digit/0","doc":"","ref":"Cogito.Primitives.html#letter_or_digit/0"},{"type":"function","title":"Cogito.Primitives.not_chars/1","doc":"","ref":"Cogito.Primitives.html#not_chars/1"},{"type":"function","title":"Cogito.Primitives.space/0","doc":"","ref":"Cogito.Primitives.html#space/0"},{"type":"function","title":"Cogito.Primitives.string/0","doc":"","ref":"Cogito.Primitives.html#string/0"},{"type":"function","title":"Cogito.Primitives.word/1","doc":"","ref":"Cogito.Primitives.html#word/1"},{"type":"function","title":"Cogito.Primitives.ws/0","doc":"","ref":"Cogito.Primitives.html#ws/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}